# Open5GS Python API Framework

This package provides a Pythonic API for interacting with Open5GS components and configuring network parameters.

## Installation

```bash
pip install open5gsapi
```

## Usage

```python
from open5gsapi import open5gs

# Configure network parameters
ambr = open5gs.ambr(value=10000000, unit=1)  # 10 Mbps
qos = open5gs.qos(index=5)
arp = open5gs.arp(priority_level=1, pre_emption_vulnerability=1, pre_emption_capability=2)

# Update configuration
open5gs.update_config(ambr=ambr, qos=qos, arp=arp)

# Get UE and UPF API URLs
UE_API_URL = open5gs.ue(8080, "send")
UPF_API_URL = open5gs.upf(8081, "receive", "sensor")

# Send data
data = {"sensor_id": 1, "temperature": 25.5, "humidity": 60}
response = open5gs.send_data(UE_API_URL, data)
print(response)

# Receive data
received_data = open5gs.receive_data(UPF_API_URL)
print(received_data)
```

## Development

To set up the development environment:

1. Clone the repository
2. Create a virtual environment: `python -m venv venv`
3. Activate the virtual environment: `source venv/bin/activate` (Linux/Mac) or `venv\Scripts\activate` (Windows)
4. Install development dependencies: `pip install -r requirements-dev.txt`
5. Run tests: `pytest tests/`
